@@ -1,5 +1,11 @@
 from .decode import cadence_object_hook
 from .encode import CadenceJsonEncoder, encode_arguments
+from .events import (
+    Event,
+    BaseEvent,
+    EventTypeRegistry,
+    EventType,
+)
 from .types import (
     Value,
     Void,
@@ -29,13 +35,28 @@ from .types import (
     UFix64,
     Array,
     Dictionary,
-    Struct,
-    Resource,
-    Event,
-    Contract,
     Link,
     Path,
-    Type,
     Capability,
     KeyValuePair,
+    TypeValue,
+)
+from .composite import (
+    Type,
+    CompositeType,
+    Struct,
+    StructType,
+    Resource,
+    ResourceType,
+    ContractType,
+    Contract,
+    Field,
+)
+from .events import AccountCreatedEvent
+from .location import (
+    StringLocation,
+    FlowLocation,
+    AddressLocation,
+    Location,
+    ScriptLocation,
 )
